@@ -139,8 +139,12 @@ The following replacements are available:
   "Name of the property for contact icon."
   :type 'string)
 
+(defcustom org-contacts-name-property "NAME"
+  "Name of the property for name match."
+  :type 'string)
+
 (defcustom org-contacts-nickname-property "NICKNAME"
-  "Name of the property for IRC nickname match."
+  "Name of the property for nickname match."
   :type 'string)
 
 (defcustom org-contacts-icon-size 64
@@ -164,14 +168,17 @@ The following replacements are available:
   :type 'string)
 
 (defcustom org-contacts-matcher
-  (mapconcat #'identity
-             (mapcar (lambda (x) (concat x "<>\"\""))
-                     (list org-contacts-email-property
-                           org-contacts-alias-property
-                           org-contacts-tel-property
-                           org-contacts-address-property
-                           org-contacts-birthday-property))
-             "|")
+  (string-join
+   (mapcar (lambda (x) (concat x "<>\"\""))
+           (list org-contacts-icon-property
+                 org-contacts-name-property
+                 org-contacts-nickname-property
+                 org-contacts-alias-property
+                 org-contacts-email-property
+                 org-contacts-tel-property
+                 org-contacts-address-property
+                 org-contacts-birthday-property))
+   "|")
   "Matching rule for finding heading that are contacts.
 This can be a tag name, or a property check."
   :type 'string)
@@ -194,6 +201,10 @@ This overrides `org-email-link-description-format' if set."
   "List of functions used to complete contacts in `message-mode'."
   :type 'hook)
 
+(defcustom org-contacts-irc-nickname-property "IRC_NICKNAME"
+  "Name of the property for IRC nickname match."
+  :type 'string)
+
 ;; Decalre external functions and variables
 (declare-function org-reverse-string "org")
 (declare-function diary-ordinal-suffix "ext:diary-lib")
@@ -320,7 +331,7 @@ buffer."
                 (goto-char (plist-get contact :position))
                 (setq epom (org-element-context)))
               (progn
-                (org-goto-marker-or-bmk (org-find-exact-headline-in-buffer name))
+                (org-goto-marker-or-bmk (org-find-exact-headline-in-buffer name (current-buffer)))
                 (setq epom (org-element-context)))))))
     epom))
 
@@ -921,11 +932,14 @@ This function should be called from `gnus-article-prepare-hook'."
 ;;====================================== org-contacts searching =====================================
 
 (defcustom org-contacts-identity-properties-list
-  `(,org-contacts-email-property
-    ,org-contacts-alias-property
-    ,org-contacts-tel-property
-    ,org-contacts-address-property
-    ,org-contacts-birthday-property)
+  (list org-contacts-icon-property
+        org-contacts-name-property
+        org-contacts-nickname-property
+        org-contacts-alias-property
+        org-contacts-email-property
+        org-contacts-tel-property
+        org-contacts-address-property
+        org-contacts-birthday-property)
   "Matching rule for finding heading that are contacts.
 This can be property key checking."
   :type '(repeat symbol)
@@ -981,32 +995,56 @@ This can be property key checking."
                       (_ (org-file-image-p avatar-absolute-path))
                       (_ (file-exists-p avatar-absolute-path)))
             avatar-absolute-path))
+         (nickname (let ((org-property-separators (list (cons org-contacts-nickname-property "[,\ ]"))))
+                     (concat (propertize "nick: " 'face '(:foreground "SlateGray4" :height 90))
+                             (propertize (or (org-entry-get headline org-contacts-nickname-property) "")
+                                         'face '(:slant italic :foreground "DarkOliveGreen1")))))
+         (email (let ((org-property-separators (list (cons org-contacts-email-property "[,\ ]"))))
+                  (concat (propertize "email: " 'face '(:foreground "SlateGray4" :height 90))
+                          (propertize (or (org-entry-get headline org-contacts-email-property) "")
+                                      'face '(:foreground "MediumPurple3")))))
+         (wechat (propertize (or (org-entry-get headline "WeChat") "")
+                             'face '(:foreground "MediumPurple3")))
+         (bio (concat (propertize "bio: " 'face '(:foreground "SlateGray4" :height 90))
+                      (propertize (string-fill (or (org-entry-get headline "Bio") "")
+                                               (or fill-column (abs org-tags-column) (- (window-width) 15)))
+                                  'face '(:height 95))))
          (info (concat "\n"
-                       (concat org-contacts-ahead-space-padding "   ")
-                       (let ((org-property-separators (list (cons org-contacts-nickname-property "[,\ ]"))))
-                         (org-entry-get headline org-contacts-nickname-property))
-                       (let ((org-property-separators (list (cons org-contacts-email-property "[,\ ]"))))
-                         (org-entry-get headline org-contacts-email-property))
+                       ;; nick name
+                       ;; (concat org-contacts-ahead-space-padding "   ") nickname "\n"
+                       ;; email
+                       (concat org-contacts-ahead-space-padding "   ") email "\n"
+                       ;; wechat
+                       (concat org-contacts-ahead-space-padding "   ") wechat "\n"
+                       ;; bio
+                       bio
                        "\n"))
-         (middle-line-length (let ((length (- (abs org-tags-column)
-                                              (length (string-join tags ":"))
-                                              (length contact-name))))
-                               (if (> length 0) length 0))))
+         (middle-line-length (abs
+                              (- (or (abs org-tags-column) (- (window-width) 5))
+                                 (length (string-join tags ":"))
+                                 (length contact-name)))))
     ;; detect whether headline is an org-contacts entry?
     (when (seq-intersection org-contacts-identity-properties-list (mapcar 'car properties))
       (propertize
        (concat
+        ;; avatar image
         (if avatar-image-path
             (propertize org-contacts-ahead-space-padding
                         'display (create-image avatar-image-path nil nil
                                                :ascent 30 ; set image baseline to align image top with candidate line.
                                                :width org-contacts-icon-size))
           org-contacts-ahead-space-padding)
-        " "
-        contact-name
-        (format " %s [%s]"
-                (make-string (or middle-line-length 0) ?―)
-                (string-join tags ":")))
+        ;; contact name
+        " " (propertize contact-name 'face '(:inherit org-level-1))
+        ;; nick name
+        " " (concat "(" nickname ")")
+        ;; middle line
+        " " (propertize (make-string (or middle-line-length 0) ?―)
+                        'face '(:foreground "SlateGray4"))
+        ;; tags
+        " " (propertize (concat "[" (string-join tags ":") "]")
+                        'face '(:inherit org-tag)))
+       ;; candidate extra properties
        'contact-name contact-name
        'annotation info))))
 
@@ -1060,11 +1098,11 @@ This can be property key checking."
      (let ((buf (find-file-noselect (expand-file-name file))))
        (with-current-buffer buf
          ;; NOTE: `org-goto-marker-or-bmk' will display buffer in current window, not follow `display-buffer' rule.
-         (when-let* ((found-contact (org-find-exact-headline-in-buffer contact-name)))
+         (when-let* ((found-contact (org-find-exact-headline-in-buffer contact-name buf)))
            (org-goto-marker-or-bmk found-contact)
            ;; FIXME: `goto-char' not physically move point in buffer.
            ;; (display-buffer buf '(display-buffer-below-selected))
-           ;; (goto-char (org-find-exact-headline-in-buffer contact-name nil t))
+           ;; (goto-char (org-find-exact-headline-in-buffer contact-name buf :pos-only))
            (org-fold-show-context)))))
    org-contacts-files))
 
@@ -1237,12 +1275,10 @@ address."
                 (cond
                  ;; [[file:dir/filename.png]]
                  ((string-match-p "\\[\\[.*\\]\\]" avatar)
-                  ;; FIXME: What if avatar matches the above regexp but the
-                  ;; one below?
+                  ;; FIXME: What if avatar matches the above regexp but the one below?
                   (when (string-match link-matcher-regexp avatar)
-                    ;; FIXME: 5 seems to be the length of `file:' but I can't
-                    ;; see anything that guarantees that the submatch 1 starts
-                    ;; with `file:'.
+                    ;; FIXME: 5 seems to be the length of `file:' but I can't see anything that
+                    ;; guarantees that the submatch 1 starts with `file:'.
                     (expand-file-name (substring (match-string-no-properties 1 avatar) 5 nil)
                                       contacts-dir)))
                  ;; "" (empty string)
@@ -1270,7 +1306,7 @@ address."
 (defun org-contacts-irc-buffer (&optional pom)
   "Get the IRC buffer associated with the entry at POM."
   (setq pom (or pom (point)))
-  (let ((nick (org-entry-get pom org-contacts-nickname-property)))
+  (let ((nick (org-entry-get pom org-contacts-irc-nickname-property)))
     (when nick
       (let ((buffer (get-buffer nick)))
         (when buffer
@@ -1619,9 +1655,9 @@ Each element has the form (NAME . (FILE . POSITION))."
      ;; jump to exact contact headline directly
      (t
       (with-current-buffer buf
-        (if-let* ((position (org-find-exact-headline-in-buffer query)))
+        (if-let* ((marker (org-find-exact-headline-in-buffer query buf)))
             (progn
-              (goto-char (marker-position position))
+              (org-goto-marker-or-bmk marker)
               (org-fold-show-context))
           (user-error "[org-contacts] Can't find <%s> in your `org-contacts-files'" query)))
       (display-buffer buf '(display-buffer-below-selected))
